@@ -1,14 +1,20 @@
-#include <sys/cdefs.h>
+#include <stdlib.h>
 #ifndef lint
 #if 0
 static char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #else
 #if defined(__NetBSD__) && defined(__IDSTRING)
-__IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.18 2000/06/07 23:54:17 explorer Exp $");
+__IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.23 2002/01/31 21:01:15 tv Exp $");
 #endif /* __NetBSD__ && __IDSTRING */
 #endif /* 0 */
 #endif /* lint */
-#include <stdlib.h>
+#ifndef __P
+#ifdef __STDC__
+#define __P(x) x
+#else
+#define __P(x) ()
+#endif
+#endif
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
@@ -18,7 +24,7 @@ __IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.18 2000/06/07 23:54:17 explorer Exp
 #define yyerrok (yyerrflag=0)
 #define YYRECOVERING (yyerrflag!=0)
 #define YYPREFIX "yy"
-#line 46 "../../fsinfo/fsi_gram.y"
+#line 45 "../../fsinfo/fsi_gram.y"
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif /* HAVE_CONFIG_H */
@@ -32,10 +38,14 @@ __IDSTRING(yyrcsid, "$NetBSD: skeleton.c,v 1.18 2000/06/07 23:54:17 explorer Exp
 #  include <alloca.h>
 # else /* not HAVE_ALLOCA_H */
 #  ifdef _AIX
-#pragma alloca
+/*
+ * This pragma directive is indented so that pre-ANSI C compilers will
+ * ignore it, rather than choke on it.
+ */
+ #pragma alloca
 #  else /* not _AIX */
 #   ifndef alloca
-  /* predefined by HP cc +Olibcalls */
+/* predefined by HP cc +Olibcalls */
 voidp alloca();
 #   endif /* not alloca */
 #  endif /* not _AIX */
@@ -43,7 +53,7 @@ voidp alloca();
 #endif /* not __GNUC__ */
 
 extern qelem *list_of_hosts, *list_of_automounts;
-#line 72 "../../fsinfo/fsi_gram.y"
+#line 75 "../../fsinfo/fsi_gram.y"
 typedef union {
 	auto_tree *a;
 	disk_fs *d;
@@ -54,7 +64,7 @@ typedef union {
 	fsi_mount *m;
 	fsmount *f;
 } YYSTYPE;
-#line 58 "y.tab.c"
+#line 68 "fsi_gram.c"
 #define tARCH 257
 #define tAS 258
 #define tAUTOMOUNT 259
@@ -84,7 +94,7 @@ typedef union {
 #define tSEL 283
 #define tSTR 284
 #define YYERRCODE 256
-short yylhs[] = {                                        -1,
+const short yylhs[] = {                                        -1,
     0,    0,    0,    7,    7,    8,    8,    9,    9,    9,
     9,    9,    9,    9,    3,    3,    3,    3,    1,    1,
    14,   14,   10,   10,    5,    5,    6,    6,    6,    6,
@@ -92,7 +102,7 @@ short yylhs[] = {                                        -1,
    12,   12,    4,    4,    4,    4,    4,   11,   11,   13,
    13,   13,   13,   13,   13,   13,
 };
-short yylen[] = {                                         2,
+const short yylen[] = {                                         2,
     0,    2,    2,    4,    5,    1,    4,    0,    6,    3,
     4,    4,    4,    4,    0,    4,    4,    4,    3,    2,
     0,    2,    0,    2,    5,    3,    0,    4,    4,    4,
@@ -100,7 +110,7 @@ short yylen[] = {                                         2,
     0,    6,    0,    3,    3,    3,    4,    0,    4,    0,
     2,    3,    3,    3,    3,    4,
 };
-short yydefred[] = {                                      1,
+const short yydefred[] = {                                      1,
     0,    0,    0,    0,    3,    2,    0,   20,    0,   36,
     6,    8,   23,   23,   22,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,    0,    0,    0,   24,    0,
@@ -115,11 +125,11 @@ short yydefred[] = {                                      1,
     0,    0,    0,    0,    0,    0,    0,   44,   45,   46,
    42,   47,
 };
-short yydgoto[] = {                                       1,
+const short yydgoto[] = {                                       1,
     5,   16,   59,  111,   29,   60,    6,   13,   17,   18,
    30,   90,   61,   10,
 };
-short yysindex[] = {                                      0,
+const short yysindex[] = {                                      0,
  -239, -253, -240, -118,    0,    0, -118,    0, -262,    0,
     0,    0,    0,    0,    0, -258, -104, -238, -238, -236,
   -33,  -32,  -30, -252, -248,  -17, -237, -243,    0, -230,
@@ -134,7 +144,7 @@ short yysindex[] = {                                      0,
  -241,   27, -195, -194, -193, -115, -192,    0,    0,    0,
     0,    0,
 };
-short yyrindex[] = {                                      0,
+const short yyrindex[] = {                                      0,
     0,    0,    1,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,    7,    0,    2,    2,  -57,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    8,
@@ -149,12 +159,12 @@ short yyrindex[] = {                                      0,
  -114,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,
 };
-short yygindex[] = {                                      0,
+const short yygindex[] = {                                      0,
     0,   47,    0,    0,    0,    0,    0,   87,    0,   81,
    77,  -14,    0,   78,
 };
 #define YYTABLESIZE 285
-short yytable[] = {                                      47,
+const short yytable[] = {                                      47,
    21,   48,   49,   21,   12,   62,   19,    4,    5,  121,
    41,   76,   41,   77,  112,    8,    2,   75,    7,    3,
    27,   15,   78,  113,   79,   20,   32,   34,   35,   28,
@@ -185,7 +195,7 @@ short yytable[] = {                                      47,
     0,    0,   21,   48,   49,    0,   48,   49,   19,    4,
     5,    0,    0,    0,   21,
 };
-short yycheck[] = {                                      61,
+const short yycheck[] = {                                      61,
     0,    0,    0,   61,  123,  125,    0,    0,    0,  125,
   125,  256,  256,  258,  256,  256,  256,  125,  272,  259,
   125,  284,  267,  265,  269,  284,  263,   61,   61,  268,
@@ -222,7 +232,7 @@ short yycheck[] = {                                      61,
 #endif
 #define YYMAXTOKEN 284
 #if YYDEBUG
-const char *yyname[] = {
+const char * const yyname[] = {
 "end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'='",0,0,0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
@@ -235,7 +245,7 @@ const char *yyname[] = {
 "tMOUNT","tNETMASK","tNETIF","tVOLNAME","tOPTS","tOS","tPASSNO","tDIRECT",
 "tSEL","tSTR",
 };
-const char *yyrule[] = {
+const char * const yyrule[] = {
 "$accept : list_of_hosts",
 "list_of_hosts :",
 "list_of_hosts : list_of_hosts host",
@@ -319,10 +329,10 @@ short *yyss;
 short *yysslim;
 YYSTYPE *yyvs;
 int yystacksize;
-/* allocate initial stack or double stack size, up to YYMAXDEPTH */
 int yyparse __P((void));
+/* allocate initial stack or double stack size, up to YYMAXDEPTH */
 static int yygrowstack __P((void));
-static int yygrowstack()
+static int yygrowstack __P((void))
 {
     int newsize, i;
     short *newss;
@@ -353,7 +363,7 @@ static int yygrowstack()
 #define YYACCEPT goto yyaccept
 #define YYERROR goto yyerrlab
 int
-yyparse()
+yyparse __P((void))
 {
     int yym, yyn, yystate;
 #if YYDEBUG
@@ -485,84 +495,84 @@ yyreduce:
     switch (yyn)
     {
 case 1:
-#line 128 "../../fsinfo/fsi_gram.y"
+#line 131 "../../fsinfo/fsi_gram.y"
 { yyval.q = new_que(); }
 break;
 case 2:
-#line 131 "../../fsinfo/fsi_gram.y"
+#line 134 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].h) ins_que((qelem *) yyvsp[0].h, list_of_hosts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 3:
-#line 135 "../../fsinfo/fsi_gram.y"
+#line 138 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].a) ins_que((qelem *) yyvsp[0].a, list_of_automounts->q_back);
 	    yyval.q = yyvsp[-1].q; }
 break;
 case 4:
-#line 146 "../../fsinfo/fsi_gram.y"
-{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
-break;
-case 5:
 #line 149 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
 break;
+case 5:
+#line 152 "../../fsinfo/fsi_gram.y"
+{ yyval.h = yyvsp[-2].h; yyval.h->h_disk_fs = yyvsp[-1].q; yyval.h->h_mount = yyvsp[0].q; }
+break;
 case 6:
-#line 155 "../../fsinfo/fsi_gram.y"
+#line 158 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 7:
-#line 158 "../../fsinfo/fsi_gram.y"
+#line 161 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_HOST, yyvsp[0].s); }
 break;
 case 8:
-#line 164 "../../fsinfo/fsi_gram.y"
+#line 167 "../../fsinfo/fsi_gram.y"
 { yyval.h = new_host(); }
 break;
 case 9:
-#line 167 "../../fsinfo/fsi_gram.y"
+#line 170 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[-1].e) {
 		yyvsp[-1].e->e_if = yyvsp[-3].s;
 		yyval.h = yyvsp[-5].h; set_host(yyval.h, HF_ETHER, (char *) yyvsp[-1].e); }
 	  }
 break;
 case 10:
-#line 173 "../../fsinfo/fsi_gram.y"
+#line 176 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-2].h; set_host(yyval.h, HF_CONFIG, yyvsp[0].s); }
 break;
 case 11:
-#line 176 "../../fsinfo/fsi_gram.y"
+#line 179 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_ARCH, yyvsp[0].s); }
 break;
 case 12:
-#line 179 "../../fsinfo/fsi_gram.y"
+#line 182 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_OS, yyvsp[0].s); }
 break;
 case 13:
-#line 182 "../../fsinfo/fsi_gram.y"
+#line 185 "../../fsinfo/fsi_gram.y"
 { yyval.h = yyvsp[-3].h; set_host(yyval.h, HF_CLUSTER, yyvsp[0].s); }
 break;
 case 14:
-#line 185 "../../fsinfo/fsi_gram.y"
+#line 188 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown host attribute"); }
 break;
 case 15:
-#line 190 "../../fsinfo/fsi_gram.y"
+#line 193 "../../fsinfo/fsi_gram.y"
 { yyval.e = new_ether_if(); }
 break;
 case 16:
-#line 193 "../../fsinfo/fsi_gram.y"
+#line 196 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_INADDR, yyvsp[0].s); }
 break;
 case 17:
-#line 195 "../../fsinfo/fsi_gram.y"
+#line 198 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_NETMASK, yyvsp[0].s); }
 break;
 case 18:
-#line 197 "../../fsinfo/fsi_gram.y"
+#line 200 "../../fsinfo/fsi_gram.y"
 { yyval.e = yyvsp[-3].e; set_ether_if(yyval.e, EF_HWADDR, yyvsp[0].s); }
 break;
 case 19:
-#line 207 "../../fsinfo/fsi_gram.y"
+#line 210 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].q) {
 		yyval.a = new_auto_tree(yyvsp[-1].s, yyvsp[0].q);
 	    } else {
@@ -571,23 +581,23 @@ case 19:
 	  }
 break;
 case 20:
-#line 215 "../../fsinfo/fsi_gram.y"
+#line 218 "../../fsinfo/fsi_gram.y"
 { yyval.a = 0; }
 break;
 case 21:
-#line 220 "../../fsinfo/fsi_gram.y"
+#line 223 "../../fsinfo/fsi_gram.y"
 { yyval.s = strdup(""); }
 break;
 case 22:
-#line 223 "../../fsinfo/fsi_gram.y"
+#line 226 "../../fsinfo/fsi_gram.y"
 { yyval.s = yyvsp[0].s; }
 break;
 case 23:
-#line 228 "../../fsinfo/fsi_gram.y"
+#line 231 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 24:
-#line 231 "../../fsinfo/fsi_gram.y"
+#line 234 "../../fsinfo/fsi_gram.y"
 { if (yyvsp[0].d) {
 		if (yyvsp[-1].q)
 			yyval.q = yyvsp[-1].q;
@@ -600,55 +610,55 @@ case 24:
 	  }
 break;
 case 25:
-#line 250 "../../fsinfo/fsi_gram.y"
+#line 253 "../../fsinfo/fsi_gram.y"
 { yyvsp[-1].d->d_dev = yyvsp[-3].s; yyval.d = yyvsp[-1].d; }
 break;
 case 26:
-#line 253 "../../fsinfo/fsi_gram.y"
+#line 256 "../../fsinfo/fsi_gram.y"
 { yyval.d = (disk_fs *) 0; }
 break;
 case 27:
-#line 269 "../../fsinfo/fsi_gram.y"
+#line 272 "../../fsinfo/fsi_gram.y"
 { yyval.d = new_disk_fs(); }
 break;
 case 28:
-#line 272 "../../fsinfo/fsi_gram.y"
+#line 275 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FSTYPE, yyvsp[0].s); }
 break;
 case 29:
-#line 275 "../../fsinfo/fsi_gram.y"
+#line 278 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_OPTS, yyvsp[0].s); }
 break;
 case 30:
-#line 278 "../../fsinfo/fsi_gram.y"
+#line 281 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_PASSNO, yyvsp[0].s); }
 break;
 case 31:
-#line 281 "../../fsinfo/fsi_gram.y"
+#line 284 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_FREQ, yyvsp[0].s); }
 break;
 case 32:
-#line 284 "../../fsinfo/fsi_gram.y"
+#line 287 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-2].d; set_disk_fs(yyval.d, DF_MOUNT, (char *) yyvsp[0].q); }
 break;
 case 33:
-#line 287 "../../fsinfo/fsi_gram.y"
+#line 290 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_DUMPSET, yyvsp[0].s); }
 break;
 case 34:
-#line 290 "../../fsinfo/fsi_gram.y"
+#line 293 "../../fsinfo/fsi_gram.y"
 { yyval.d = yyvsp[-3].d; set_disk_fs(yyval.d, DF_LOG, yyvsp[0].s); }
 break;
 case 35:
-#line 293 "../../fsinfo/fsi_gram.y"
+#line 296 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown filesystem attribute"); }
 break;
 case 36:
-#line 307 "../../fsinfo/fsi_gram.y"
+#line 310 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 37:
-#line 310 "../../fsinfo/fsi_gram.y"
+#line 313 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
 	    a->a_volname = yyvsp[0].s;
 	    a->a_opts = yyvsp[-2].s;
@@ -660,7 +670,7 @@ case 37:
 	  }
 break;
 case 38:
-#line 320 "../../fsinfo/fsi_gram.y"
+#line 323 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-3].s);
             a->a_hardwiredfs = yyvsp[0].s;
             a->a_opts = yyvsp[-2].s;
@@ -672,7 +682,7 @@ case 38:
           }
 break;
 case 39:
-#line 331 "../../fsinfo/fsi_gram.y"
+#line 334 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-2].s);
 	    a->a_symlink = yyvsp[0].s;
 	    if (yyvsp[-3].q)
@@ -683,7 +693,7 @@ case 39:
 	  }
 break;
 case 40:
-#line 341 "../../fsinfo/fsi_gram.y"
+#line 344 "../../fsinfo/fsi_gram.y"
 { automount *a = new_automount(yyvsp[-4].s);
 	    a->a_mount = yyvsp[-1].q;
 	    a->a_opts = yyvsp[-3].s;
@@ -695,11 +705,11 @@ case 40:
 	  }
 break;
 case 41:
-#line 354 "../../fsinfo/fsi_gram.y"
+#line 357 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 42:
-#line 357 "../../fsinfo/fsi_gram.y"
+#line 360 "../../fsinfo/fsi_gram.y"
 { yyvsp[-2].m->m_mount = yyvsp[-1].q;
 	    yyvsp[-2].m->m_name = yyvsp[-4].s;
 	    if (yyvsp[-4].s[0] != '/' && yyvsp[-4].s[1] && strchr(yyvsp[-4].s+1, '/'))
@@ -712,31 +722,31 @@ case 42:
 	  }
 break;
 case 43:
-#line 371 "../../fsinfo/fsi_gram.y"
+#line 374 "../../fsinfo/fsi_gram.y"
 { yyval.m = new_mount(); }
 break;
 case 44:
-#line 374 "../../fsinfo/fsi_gram.y"
+#line 377 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_EXPORTFS, yyvsp[0].s); }
 break;
 case 45:
-#line 377 "../../fsinfo/fsi_gram.y"
+#line 380 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_VOLNAME, yyvsp[0].s); }
 break;
 case 46:
-#line 380 "../../fsinfo/fsi_gram.y"
+#line 383 "../../fsinfo/fsi_gram.y"
 { yyval.m = yyvsp[-2].m; set_mount(yyval.m, DM_SEL, yyvsp[0].s); }
 break;
 case 47:
-#line 383 "../../fsinfo/fsi_gram.y"
+#line 386 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown directory attribute"); }
 break;
 case 48:
-#line 393 "../../fsinfo/fsi_gram.y"
+#line 396 "../../fsinfo/fsi_gram.y"
 { yyval.q = 0; }
 break;
 case 49:
-#line 396 "../../fsinfo/fsi_gram.y"
+#line 399 "../../fsinfo/fsi_gram.y"
 { set_fsmount(yyvsp[0].f, FM_VOLNAME, yyvsp[-1].s);
 	    if (yyvsp[-3].q)
 		yyval.q = yyvsp[-3].q;
@@ -746,34 +756,34 @@ case 49:
 	    }
 break;
 case 50:
-#line 416 "../../fsinfo/fsi_gram.y"
+#line 419 "../../fsinfo/fsi_gram.y"
 { yyval.f = new_fsmount(); }
 break;
 case 51:
-#line 419 "../../fsinfo/fsi_gram.y"
+#line 422 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-1].f; set_fsmount(yyval.f, FM_DIRECT, ""); }
 break;
 case 52:
-#line 422 "../../fsinfo/fsi_gram.y"
+#line 425 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_LOCALNAME, yyvsp[0].s); }
 break;
 case 53:
-#line 425 "../../fsinfo/fsi_gram.y"
+#line 428 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FROM, yyvsp[0].s); }
 break;
 case 54:
-#line 428 "../../fsinfo/fsi_gram.y"
+#line 431 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_FSTYPE, yyvsp[0].s); }
 break;
 case 55:
-#line 431 "../../fsinfo/fsi_gram.y"
+#line 434 "../../fsinfo/fsi_gram.y"
 { yyval.f = yyvsp[-2].f; set_fsmount(yyval.f, FM_OPTS, yyvsp[0].s); }
 break;
 case 56:
-#line 434 "../../fsinfo/fsi_gram.y"
+#line 437 "../../fsinfo/fsi_gram.y"
 { yyerror("unknown mount attribute"); }
 break;
-#line 777 "y.tab.c"
+#line 787 "fsi_gram.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
